@@ -25,7 +25,7 @@ from __future__ import (division as _py3_division,
                         unicode_literals as _py3_unicode)
 
 from re import compile as _regex_compile
-from xoutil.six import string_types
+from six import string_types
 
 
 from xoutil.names import strlist as strs
